@@ -132,7 +132,11 @@ where
         obj_info.parts * obj_info.size as u64
     );
     let dir = init_download_dir(download_path).await?;
-    let mut dest = TempFile::new(dir, None).await?;
+    let mut dest = if let Some(tmp) = Config::global().temp_dir_path() {
+        TempFile::new(tmp, None).await?
+    } else {
+        TempFile::new(dir, None).await?
+    };
 
     if transparent_decompression && obj_info.is_esthri_compressed() {
         let stream = download_streaming_helper(s3, bucket, key, obj_info.parts);
