@@ -117,7 +117,75 @@ where
     );
 
     let compressed = false;
-    upload_file_helper(s3, bucket.as_ref(), key.as_ref(), file.as_ref(), compressed).await
+    upload_file_helper(
+        s3,
+        bucket.as_ref(),
+        key.as_ref(),
+        file.as_ref(),
+        compressed,
+        Config::global().storage_class(),
+    )
+    .await
+}
+
+#[logfn(err = "ERROR")]
+pub async fn upload_with_storage_class<T>(
+    s3: &T,
+    bucket: impl AsRef<str>,
+    key: impl AsRef<str>,
+    file: impl AsRef<Path>,
+    storage_class: S3StorageClass,
+) -> Result<()>
+where
+    T: S3,
+{
+    info!(
+        "put: bucket={}, key={}, file={}",
+        bucket.as_ref(),
+        key.as_ref(),
+        file.as_ref().display()
+    );
+
+    let compressed = false;
+    upload_file_helper(
+        s3,
+        bucket.as_ref(),
+        key.as_ref(),
+        file.as_ref(),
+        compressed,
+        storage_class,
+    )
+    .await
+}
+
+#[logfn(err = "ERROR")]
+pub async fn upload_compressed_with_storage_class<T>(
+    s3: &T,
+    bucket: impl AsRef<str>,
+    key: impl AsRef<str>,
+    file: impl AsRef<Path>,
+    storage_class: S3StorageClass,
+) -> Result<()>
+where
+    T: S3,
+{
+    info!(
+        "put: bucket={}, key={}, file={}",
+        bucket.as_ref(),
+        key.as_ref(),
+        file.as_ref().display()
+    );
+
+    let compressed = true;
+    upload_file_helper(
+        s3,
+        bucket.as_ref(),
+        key.as_ref(),
+        file.as_ref(),
+        compressed,
+        storage_class,
+    )
+    .await
 }
 
 #[logfn(err = "ERROR")]
@@ -138,7 +206,15 @@ where
     );
 
     let compressed = true;
-    upload_file_helper(s3, bucket.as_ref(), key.as_ref(), file.as_ref(), compressed).await
+    upload_file_helper(
+        s3,
+        bucket.as_ref(),
+        key.as_ref(),
+        file.as_ref(),
+        compressed,
+        S3StorageClass::StandardIA,
+    )
+    .await
 }
 
 #[logfn(err = "ERROR")]
@@ -150,34 +226,62 @@ pub async fn upload_from_reader<T, R>(
     file_size: u64,
     metadata: Option<HashMap<String, String>>,
 ) -> Result<()>
+where
+    T: S3,
+    R: AsyncRead + AsyncSeek + Unpin + Send + 'static,
+{
+    upload_from_reader_with_storage_class(
+        s3,
+        bucket,
+        key,
+        reader,
+        file_size,
+        metadata,
+        S3StorageClass::StandardIA,
+    )
+    .await
+}
+
+#[logfn(err = "ERROR")]
+pub async fn upload_from_reader_with_storage_class<T, R>(
+    s3: &T,
+    bucket: impl AsRef<str>,
+    key: impl AsRef<str>,
+    reader: R,
+    file_size: u64,
+    metadata: Option<HashMap<String, String>>,
+    storage_class: S3StorageClass,
+) -> Result<()>
 where
     T: S3,
     R: AsyncRead + AsyncSeek + Unpin + Send + 'static,
 {
     let (bucket, key) = (bucket.as_ref(), key.as_ref());
     info!(
-        "put: bucket={}, key={}, file_size={}",
-        bucket, key, file_size
+        "put: bucket={}, key={}, file_size={}, storage_class={}",
+        bucket, key, file_size, storage_class
     );
 
     if file_size == 0 {
         debug!("uploading empty file");
-        empty_upload(s3, bucket, key, metadata).await
+        empty_upload(s3, bucket, key, metadata, storage_class).await
     } else if file_size < Config::global().upload_part_size() {
         debug!("uploading singlepart file");
-        singlepart_upload(s3, bucket, key, reader, file_size, metadata).await
+        singlepart_upload(s3, bucket, key, reader, file_size, metadata, storage_class).await
     } else {
         debug!("uploading multipart file");
-        multipart_upload(s3, bucket, key, reader, file_size, metadata).await
+        multipart_upload(s3, bucket, key, reader, file_size, metadata, storage_class).await
     }
 }
 
-async fn upload_file_helper<T>(
+#[logfn(err = "ERROR")]
+pub async fn upload_file_helper<T>(
     s3: &T,
     bucket: &str,
     key: &str,
     path: &Path,
     compressed: bool,
+    storage_class: S3StorageClass,
 ) -> Result<()>
 where
     T: S3,
@@ -185,13 +289,14 @@ where
     let key = format_key(key, path)?;
     if compressed {
         let (mut tmp, size) = compress_to_tempfile(path).await?;
-        upload_from_reader(
+        upload_from_reader_with_storage_class(
             s3,
             bucket,
             key,
             tmp.take_file(),
             size,
             Some(crate::compression::compressed_file_metadata()),
+            storage_class,
         )
         .await?;
         Ok(())
@@ -199,7 +304,7 @@ where
         let f = File::open(path).await?;
         let size = f.metadata().await?.len();
         debug!("upload: file size: {}", size);
-        upload_from_reader(s3, bucket, key, f, size, None).await
+        upload_from_reader_with_storage_class(s3, bucket, key, f, size, None, storage_class).await
     }
 }
 
@@ -208,6 +313,7 @@ async fn empty_upload<T>(
     bucket: &str,
     key: &str,
     metadata: Option<HashMap<String, String>>,
+    storage_class: S3StorageClass,
 ) -> Result<()>
 where
     T: S3,
@@ -218,6 +324,7 @@ where
             key: key.into(),
             acl: Some("bucket-owner-full-control".into()),
             metadata: metadata.as_ref().cloned(),
+            storage_class: Some(storage_class.to_string()),
             ..Default::default()
         })
         .await
@@ -234,6 +341,7 @@ async fn singlepart_upload<T, R>(
     reader: R,
     file_size: u64,
     metadata: Option<HashMap<String, String>>,
+    storage_class: S3StorageClass,
 ) -> Result<()>
 where
     T: S3,
@@ -255,6 +363,7 @@ where
             body: Some(into_byte_stream(body.clone())),
             acl: Some("bucket-owner-full-control".into()),
             metadata: metadata.as_ref().cloned(),
+            storage_class: Some(storage_class.to_string()),
             ..Default::default()
         })
         .await
@@ -271,12 +380,13 @@ async fn multipart_upload<T, R>(
     reader: R,
     file_size: u64,
     metadata: Option<HashMap<String, String>>,
+    storage_class: S3StorageClass,
 ) -> Result<()>
 where
     T: S3,
     R: AsyncRead + AsyncSeek + Unpin + Send + 'static,
 {
-    let upload_id = create_multipart_upload(s3, bucket, key, metadata)
+    let upload_id = create_multipart_upload(s3, bucket, key, metadata, storage_class)
         .await?
         .upload_id
         .ok_or(Error::UploadIdNone)?;
